<template>
    <div
        class="reform-pilot-containter"
        v-loading="loading"
        :element-loading-background="loadingColor"
    >
        <div id="trend-chart"></div>
        <div class="table-value">
            <div>
                月度目标完成率:
                <span>{{ rateData && rateData.finishStartMonthRate }}%</span>
            </div>
            <div>
                年度目标完成率:
                <span>{{ rateData && rateData.finishStartYearRate }}%</span>
            </div>
        </div>
    </div>
</template>

<script>
import * as echarts from 'echarts'
import apiList from '@/api/bigScreen/projectSub.js'
export default {
    name: 'projectTrendChart',
    data() {
        return {
            loadingColor: 'rgba(6, 46, 106, 1)',
            loading: false,
            trendChart: null,
            trendChartOption: null,
            legendData: [],
            xAxisData: [],
            seriesData: [],
            valueData: [],
            rateData: null,
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.$emit('searchDateChange')
        this.loadData()
        this.$bus.$on('changeDate', () => {
            this.loadData()
        })
    },
    methods: {
        initTrendChart() {
            let chartDom = document.getElementById('trend-chart')
            this.trendChart = echarts.init(chartDom)
            this.trendChartOption = {
                tooltip: {
                    trigger: 'axis',
                    backgroundColor: 'rgba(6, 47, 107, 1)',
                    borderColor: 'rgba(2, 115, 233, 1)',
                    textStyle: {
                        color: '#fff',
                        fontSize: 18,
                    },
                    formatter: (arg) => {
                        let str = arg[0].axisValue + '</br>'
                        arg.forEach((item) => {
                            if (
                                Object.keys(this.valueData[item.dataIndex])
                                    .length
                            ) {
                                str =
                                    str +
                                    '<span style="display:inline-block;font-size:18px;margin-top:5px;">' +
                                    item.seriesName +
                                    '</span>' +
                                    '</br>' +
                                    '&nbsp;&nbsp;&nbsp;月度实际累计完成值' +
                                    ' : ' +
                                    item.data +
                                    '</br>' +
                                    item.marker +
                                    '已完成当月目标值/未完成当月目标值' +
                                    ' : ' +
                                    this.valueData[item.dataIndex][
                                        item.seriesName
                                    ].addValue +
                                    '/' +
                                    this.valueData[item.dataIndex][
                                        item.seriesName
                                    ].unStartAddValue +
                                    '</br>' +
                                    '&nbsp;&nbsp;&nbsp;已完成年度目标值/未完成年度目标值' +
                                    ' : ' +
                                    this.valueData[item.dataIndex][
                                        item.seriesName
                                    ].value +
                                    '/' +
                                    this.valueData[item.dataIndex][
                                        item.seriesName
                                    ].unStartValue +
                                    '</br>'
                            } else {
                                str =
                                    str +
                                    '<span style="display:inline-block;font-size:18px;margin-top:5px;">' +
                                    item.seriesName +
                                    '</span>' +
                                    '</br>' +
                                    '&nbsp;&nbsp;&nbsp;月度实际完成值' +
                                    ' : ' +
                                    item.data +
                                    '</br>' +
                                    item.marker +
                                    '已完成当月目标值/未完成当月目标值' +
                                    ' : ' +
                                    0 +
                                    '/' +
                                    0 +
                                    '</br>' +
                                    '&nbsp;&nbsp;&nbsp;已完成年度目标值/未完成年度目标值' +
                                    ' : ' +
                                    0 +
                                    '/' +
                                    0 +
                                    '</br>'
                            }
                        })
                        return str
                    },
                },
                legend: {
                    top: '0',
                    left: 'center',
                    type: 'plain',
                    icon: 'rect',
                    inactiveColor: '#333333',
                    itemWidth: 20,
                    itemHeight: 6,
                    textStyle: {
                        color: '#B1E3FF',
                        fontSize: 16,
                    },
                    data: this.legendData,
                },
                grid: {
                    left: '1%',
                    right: '2%',
                    bottom: '2%',
                    containLabel: true,
                },

                xAxis: {
                    type: 'category',
                    type: 'category',
                    boundaryGap: ['0%', '0%'],
                    axisLine: {
                        lineStyle: {
                            color: 'rgba(154,199,220, 0.2)',
                        },
                    },
                    axisLabel: {
                        color: '#D7F1FF',
                        align: 'center',
                        fontSize: 16,
                        padding: [0, 0, 0, 10],
                    },
                    boundaryGap: false,
                    data: this.xAxisData,
                    splitLine: {
                        show: false,
                    },
                },
                yAxis: {
                    type: 'value',
                    axisLabel: {
                        color: '#D7F1FF',
                        interval: 0,
                        showMinLabel: true,
                        showMaxLabel: true,
                        fontSize: 16,
                    },
                    axisLine: {
                        lineStyle: {
                            color: 'rgba(154,199,220, 0.2)',
                        },
                    },
                    splitLine: {
                        lineStyle: {
                            color: 'rgba(154,199,220, 0.2)',
                        },
                    },
                },
                series: this.seriesData,
            }
            this.trendChartOption &&
                this.trendChart.setOption(this.trendChartOption)
            window.addEventListener('resize', () => this.trendChart.resize())
        },
        loadData() {
            this.loading = true
            this.$nextTick(this.initTrendChart())
            let data = JSON.parse(sessionStorage.getItem('searchDate'))
            data.projectId = this.$route.query.id
            this.getTwoRate(data)
            apiList.getTrendChartData(data, (res) => {
                this.xAxisData = res.map((item) => {
                    if (item.month < 10) {
                        item.date = item.year + '/0' + item.month
                    } else {
                        item.date = item.year + '/' + item.month
                    }
                    return item.date
                })
                this.xAxisData.reverse()
                this.legendData = res[0].quantitativeObjectivesVoList.map(
                    (item) => item.objectIvesName
                )
                let arr = res.map((item) => {
                    let obj = {}
                    item.quantitativeObjectivesVoList.forEach((item1) => {
                        obj[item1.objectIvesName] = item1
                    })
                    return obj
                })
                this.valueData = JSON.parse(JSON.stringify(arr.reverse()))
                this.legendData.forEach((item, index) => {
                    this.seriesData[index] = {
                        name: item,
                        stack: 'Total',
                        type: 'line',
                        data: arr.map((item1) => {
                            return item1[item] ? item1[item].addValue : 0
                        }),
                    }
                })
                this.initTrendChart()
                this.loading = false
            })
        },
        getTwoRate(data) {
            apiList.getTwoRate(data, (res) => {
                this.rateData = res
            })
        },
    },
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/big-screen.scss';

.reform-pilot-containter {
    width: 100%;
    height: 100%;
    box-sizing: border-box;
    padding-top: 10px;

    #trend-chart {
        width: 100%;
        height: calc(100% - 80PX);
    }

    .table-value {
        width: 100%;
        height: 80PX;
        display: flex;
        justify-content: space-between;
        border-top: 1px solid #1b4272;

        >div {
            font-size: 20PX;
            height: 100%;
            width: 48%;
            font-weight: bold;
            line-height: 80PX;

            &:first-child {
                width: 50%;
                padding-right: 2%;
                text-align: right;
                border-right: 1px solid #1b4272;
            }

            >span {
                font-size: 20PX;
                font-weight: bold;
                color: rgb(150, 255, 202);
            }
        }

    }
}
</style>